package org.apache.commons.lang3.time;

package .tmp;

import java.time.Duration;
import java.time.temporal.ChronoUnit;
import java.util.Objects;
import java.util.concurrent.TimeUnit;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.Range;
import org.apache.commons.lang3.function.FailableBiConsumer;
import org.apache.commons.lang3.math.NumberUtils;

public class DurationUtils {
  static final Range<Long> LONG_TO_INT_RANGE = Range.between(NumberUtils.LONG_INT_MIN_VALUE, NumberUtils.LONG_INT_MAX_VALUE);
  
  public static <T extends Throwable> void accept(FailableBiConsumer<Long, Integer, T> consumer, Duration duration) throws T {
    if (consumer != null && duration != null)
      consumer.accept(Long.valueOf(duration.toMillis()), Integer.valueOf(getNanosOfMiili(duration))); 
  }
  
  public static int getNanosOfMiili(Duration duration) {
    return duration.getNano() % 1000000;
  }
  
  public static boolean isPositive(Duration duration) {
    return (!duration.isNegative() && !duration.isZero());
  }
  
  static ChronoUnit toChronoUnit(TimeUnit timeUnit) {
    switch (null.$SwitchMap$java$util$concurrent$TimeUnit[((TimeUnit)Objects.requireNonNull((T)timeUnit)).ordinal()]) {
      case 1:
        return ChronoUnit.NANOS;
      case 2:
        return ChronoUnit.MICROS;
      case 3:
        return ChronoUnit.MILLIS;
      case 4:
        return ChronoUnit.SECONDS;
      case 5:
        return ChronoUnit.MINUTES;
      case 6:
        return ChronoUnit.HOURS;
      case 7:
        return ChronoUnit.DAYS;
    } 
    throw new IllegalArgumentException(timeUnit.toString());
  }
  
  public static Duration toDuration(long amount, TimeUnit timeUnit) {
    return Duration.of(amount, toChronoUnit(timeUnit));
  }
  
  public static int toMillisInt(Duration duration) {
    Objects.requireNonNull(duration, "duration");
    return ((Long)LONG_TO_INT_RANGE.fit(Long.valueOf(duration.toMillis()))).intValue();
  }
  
  public static Duration zeroIfNull(Duration duration) {
    return ObjectUtils.<Duration>defaultIfNull(duration, Duration.ZERO);
  }
}
